# Blueprint

> see https://aka.ms/autorest

This is the AutoRest configuration file for Blueprint.

---
## Getting Started
To build the SDK for Blueprint, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information
These are the global settings for the Blueprint API.

``` yaml
title: BlueprintManagementClient
description: Blueprint Client
openapi-type: arm
tag: package-2017-11-preview
```


### Tag: package-2017-11-preview

These settings apply only when `--tag=package-2017-11-preview` is specified on the command line.

``` yaml $(tag) == 'package-2017-11-preview'
input-file:
- Microsoft.Blueprint/preview/2017-11-11-preview/blueprint.json
```

---
# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  namespace: Microsoft.Azure.Management.Blueprint
  payload-flattening-threshold: 1
  license-header: MICROSOFT_MIT_NO_VERSION
  output-folder: $(csharp-sdks-folder)/Blueprint/Management.Blueprint/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.blueprint
  package-name: azure-mgmt-blueprint
  title: BlueprintManagementClient
  description: The Blueprint Client.
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-blueprint/azure/mgmt/blueprint
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-blueprint
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: true
  namespace: com.microsoft.azure.management.blueprint
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-blueprint
```


## Suppression


``` yaml
directive:
  - from: blueprint.json
    suppress: R3006  # BodyTopLevelProperties/R3006/RPCViolation
    reason: properties etag defined as eTag in model
  - from: blueprint.json
    suppress: R3026 # Tracked resource 'XXX' must have patch operation that at least supports the update of tags.
    reason: Assignment is proxy resource.
  - from: blueprint.json
    suppress: UniqueResourcePaths
    where: $.paths
    reason: Microsoft.Management is a proxy resource provider
  - from: blueprint.json
    suppress: OperationsAPIImplementation
    where: $.paths
    reason: OperationsAPI for Microsoft.Management is out of scope.
```
